from .version import __version__
from .flops_counter import *
from .meanstd import *
from .fit import learning
from .utils import CrossEntropyLabelSmooth , get_learning_rate, create_exp_dir, save_checkpoint
from .autoaugment import *